==> apex_flutter_plugin-1.0.15.tar.gz: lib/api/base_request.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';

class BaseRequest {
  /// Defines The request method which can be [Method.POST] or [Method.GET]
  Method method;

  // The request parameters
  Map<String, dynamic> _params = new Map();

  BaseRequest(this._params, {this.method = Method.POST}) {
    if (_params == null) _params = new Map();
  }

  /// This adds an entry with [key] and [value] into [_params] map
  void addParam({@required String key, @required dynamic value}) {
    _params[key] = value;
  }

  /// This add a map [values] into [_params] map
  void addParams(Map<String, dynamic> values) {
    _params.addAll(values);
  }

  /// Removes a param with [key] key from [_params]
  void removeParam({@required String key}) {
    _params?.remove(key);
  }

  /// Clears [_params] map
  void clearParams() {
    _params?.clear();
  }

  /// Convert params map to query for using in requests with [Method.GET] method
  ///
  /// Returns query format of [_params] something like this `?firstKey=firstValue&secondKey=secondValue`
  String params2Query() {
    String q = "?";
    _params.forEach((key, value) {
      q += key + "=" + value.toString() + "&";
    });
    return q;
  }

  /// Converts [_params] to Json
  ///
  /// Returns encoded json as [String]
  String toJson() {
    return jsonEncode(_params ?? {});
  }
}

enum Method { POST, GET }

extension MethodExtension on Method {
  String get value {
    switch (this) {
      case Method.GET:
        return "GET";
      case Method.POST:
        return "POST";
      default:
        return "POST";
    }
  }
}

==> apex_flutter_plugin-4.0.2.tar.gz: lib/api/base_request.dart <==
import 'dart:convert';

import 'package:flutter/foundation.dart';

class BaseRequest {
  /// Defines The request method which can be [Method.POST] or [Method.GET]
  Method method;

  // The request parameters
  Map<String, dynamic> _params = new Map();

  BaseRequest(this._params, {this.method = Method.POST}) {
    if (_params == null) _params = new Map();
  }

  bool has(String key) {
    return _params.containsKey(key);
  }

  /// This adds an entry with [key] and [value] into [_params] map
  void addParam({required String key, required dynamic value}) {
    _params[key] = value;
  }

  /// This add a map [values] into [_params] map
  void addParams(Map<String, dynamic> values) {
    _params.addAll(values);
  }

  /// Removes a param with [key] key from [_params]
  void removeParam({required String key}) {
    _params?.remove(key);
  }

  /// Clears [_params] map
  void clearParams() {
    _params?.clear();
  }

  /// Convert params map to query for using in requests with [Method.GET] method
  ///
  /// Returns query format of [_params] something like this `?firstKey=firstValue&secondKey=secondValue`
  String params2Query() {
    String q = "?";
    _params.forEach((key, value) {
      q += key + "=" + value.toString() + "&";
    });
    return q;
  }

  /// Converts [_params] to Json
  ///
  /// Returns encoded json as [String]
  String toJson() {
    return jsonEncode(_params ?? {});
  }
}

enum Method { POST, GET }

extension MethodExtension on Method {
  String get value {
    switch (this) {
      case Method.GET:
        return "GET";
      case Method.POST:
        return "POST";
      default:
        return "POST";
    }
  }
}
